@@ -28,8 +28,6 @@ from .swagger.api.ap_is import (
     get_pipeline_api_client,
     get_pipeline_api_clients,
     get_pipeline_apis,
-    replace_model_api,
-    replace_pipeline_api,
 )
 from .swagger.api.data import (
     apply_data_prep_steps,
@@ -57,11 +55,8 @@ from .swagger.api.models import (
     delete_model,
     edit_model,
     get_model,
-    get_model_result_csv_data,
-    get_model_result_parquet_data,
     get_models,
     optimize_decisioning_model,
-    save_model_result,
     stop_model,
 )
 from .swagger.api.pipelines import (
@@ -113,14 +108,12 @@ ValidDataPrepStepType = Union[
     dto.FilterRowsStep,
     dto.GroupByStep,
     dto.MergeColumnsStep,
-    dto.NormalizeTextStep,
     dto.RenameStep,
     dto.ReplaceStep,
     dto.SentimentAnalysisStep,
     dto.SetColumnLevelStep,
     dto.SetColumnTypeStep,
     dto.SetTimeIndexStep,
-    dto.SimplifyCategoriesStep,
     dto.SplitColumnStep,
     dto.TransformTextStep,
 ]
@@ -428,9 +421,7 @@ class AnalyzeSwaggerClientWrapper:
         data_partition_method: dto.DataPartitionMethod = dto.DataPartitionMethod.RANDOM,
         partition_column: Optional[str] = None,
         order_by_column: Optional[str] = None,
-        weight_column: Optional[str] = None,
         wait_until_complete: bool = True,
-        model_types: Optional[List[dto.ClassificationModelType]] = None,
     ) -> int:
         payload = dto.CreateClassificationRequest(
             name=name,
@@ -447,8 +438,6 @@ class AnalyzeSwaggerClientWrapper:
             no_mixing_columns=no_mixing_columns or UNSET,
             partition_column=partition_column or UNSET,
             order_by_column=order_by_column or UNSET,
-            weight_column=weight_column or UNSET,
-            model_types=model_types or UNSET,
         )
 
         model_id = check_exists(
@@ -477,9 +466,7 @@ class AnalyzeSwaggerClientWrapper:
         data_partition_method: dto.DataPartitionMethod = dto.DataPartitionMethod.RANDOM,
         partition_column: Optional[str] = None,
         order_by_column: Optional[str] = None,
-        weight_column: Optional[str] = None,
         wait_until_complete: bool = True,
-        model_types: Optional[List[dto.RegressionModelType]] = None,
     ) -> int:
         payload = dto.CreateRegressionRequest(
             name=name,
@@ -496,8 +483,6 @@ class AnalyzeSwaggerClientWrapper:
             no_mixing_columns=no_mixing_columns or UNSET,
             partition_column=partition_column or UNSET,
             order_by_column=order_by_column or UNSET,
-            weight_column=weight_column or UNSET,
-            model_types=model_types or UNSET,
         )
         model_id = check_exists(
             create_regression_model.sync(client=self._client, json_body=payload)
@@ -712,57 +697,6 @@ class AnalyzeSwaggerClientWrapper:
     def stop_optimization(self, model_id: int):
         stop_model.sync(client=self._client, id=model_id)
 
-    def download_model_results_as_csv(
-        self,
-        model_id: int,
-        output_file: Union[str, PathLike],
-        separator: str = ",",
-        quote_char: str = '"',
-        escape_char: str = "\\",
-    ) -> None:
-        response = get_model_result_csv_data.sync_detailed(
-            client=self._client,
-            id=model_id,
-            separator=separator,
-            quote_char=quote_char,
-            escape_char=escape_char,
-        )
-        if response.status_code != 200:
-            raise ValueError(
-                f"Error obtaining model results from server: {str(response.content)}"
-            )
-        with open(output_file, "bw") as file:
-            file.write(response.content)
-
-    def _get_model_results_bytes_as_parquet(self, model_id: int) -> bytes:
-        response = get_model_result_parquet_data.sync_detailed(
-            client=self._client, id=model_id
-        )
-        if response.status_code != 200:
-            raise ValueError(
-                f"Error obtaining model results from server: {str(response.content)}"
-            )
-        return response.content
-
-    def download_model_results_as_parquet(
-        self, model_id: int, output_file: Union[str, PathLike]
-    ) -> None:
-        with open(output_file, "bw") as file:
-            parquet_bytes = self._get_model_results_bytes_as_parquet(model_id)
-            file.write(parquet_bytes)
-
-    def get_model_results_as_pandas(self, model_id: int) -> pd.DataFrame:
-        stream = io.BytesIO(self._get_model_results_bytes_as_parquet(model_id))
-        return pd.read_parquet(stream)
-
-    def save_model_results_as_data_set(
-        self, model_id: int, name: str, description: Optional[str] = None
-    ) -> int:
-        payload = dto.SaveModelResultsRequest(name=name, description=description)
-        return check_exists(
-            save_model_result.sync(client=self._client, id=model_id, json_body=payload)
-        ).id
-
     ###############
     # Prediction
     ###############
@@ -1012,20 +946,6 @@ class AnalyzeSwaggerClientWrapper:
             get_model_api.sync(client=self._client, model_api_id=api_id)
         )
 
-    def replace_model_api_model(
-        self, api_id: int, new_model_id: int, notes: str
-    ) -> int:
-        response = replace_model_api.sync_detailed(
-            client=self._client,
-            model_api_id=api_id,
-            json_body=dto.UpdateDeployedModelApiRequest(
-                new_model_id=new_model_id, notes=notes
-            ),
-        )
-        return wait_for_future_to_succeed(self._client, response).additional_properties[
-            "id"
-        ]
-
     def list_model_api_clients(
         self, api_id: int
     ) -> List[dto.DeployedApiClientResponse]:
@@ -1102,20 +1022,6 @@ class AnalyzeSwaggerClientWrapper:
             get_pipeline_api.sync(client=self._client, pipeline_api_id=api_id)
         )
 
-    def replace_pipeline_api_pipeline(
-        self, api_id: int, new_pipeline_id: int, notes: str
-    ) -> int:
-        response = replace_pipeline_api.sync_detailed(
-            client=self._client,
-            pipeline_api_id=api_id,
-            json_body=dto.UpdateDeployedPipelineApiRequest(
-                new_pipeline_id=new_pipeline_id, notes=notes
-            ),
-        )
-        return wait_for_future_to_succeed(self._client, response).additional_properties[
-            "id"
-        ]
-
     def list_pipeline_api_clients(
         self, api_id: int
     ) -> List[dto.DeployedApiClientResponse]:
